@@ -14,7 +14,7 @@ import inspect
 import json
 import re
 
-from typing import Any, TypeVar
+from typing import Any, List, TypeVar
 
 import click
 from click.decorators import group, pass_obj
@@ -322,9 +322,12 @@ class ClickParser:
 
     #: list: Arguments to be passed to each command in the parser.
     #: Note that the command is always passed first.
-    parser_args: list[Any] = []
+    parser_args: List[Any] = []
     parser = command_parser
 
+    #: dict: Parameters to be set in the context object.
+    context_obj = {}
+
     # For type hints
     log: SDSSLogger
     name: str
@@ -359,14 +362,16 @@ class ClickParser:
         # the default handling of exceptions in Click. This will force
         # exceptions to be raised instead of redirected to the stdout.
         # See http://click.palletsprojects.com/en/7.x/exceptions/
+        obj = {
+            "parser_args": parser_args,
+            "log": self.log,
+            "exception_handler": self._handle_command_exception,
+        }
+        obj.update(self.context_obj)
         ctx = self.parser.make_context(
             f"{self.name}-command-parser",
             command_args,
-            obj={
-                "parser_args": parser_args,
-                "log": self.log,
-                "exception_handler": self._handle_command_exception,
-            },
+            obj=obj,
         )
 
         # Makes sure this is the global context. This solves problems when
